Learn R Programming

dlmtree (version 1.1.1)

dlmtree-package: dlmtree: Bayesian Treed Distributed Lag Models

Description

logo

Estimation of distributed lag models (DLMs) based on a Bayesian additive regression trees framework. Includes several extensions of DLMs: treed DLMs and distributed lag mixture models (Mork and Wilson, 2023) tools:::Rd_expr_doi("10.1111/biom.13568"); treed distributed lag nonlinear models (Mork and Wilson, 2022) tools:::Rd_expr_doi("10.1093/biostatistics/kxaa051"); heterogeneous DLMs (Mork, et. al., 2024) tools:::Rd_expr_doi("10.1080/01621459.2023.2258595"); monotone DLMs (Mork and Wilson, 2024) tools:::Rd_expr_doi("10.1214/23-BA1412"). The package also includes visualization tools and a 'shiny' interface to check model convergence and to help interpret results.

Arguments

Author

Maintainer: Daniel Mork dmork@hsph.harvard.edu (ORCID) [copyright holder]

Authors:

See Also