Diagnostic control settings for dlmtree model fitting
dlmtree.control.diagnose(
subset = NULL,
lowmem = FALSE,
verbose = TRUE,
save.data = TRUE,
diagnostics = FALSE,
initial.params = NULL
)list of control parameters for diagnostics.
integer vector to analyze only a subset of data and exposures.
TRUE or FALSE (default): turn on memory saver for DLNM, slower computation time.
TRUE (default) or FALSE: print output
TRUE (default) or FALSE: save data used for model fitting. This must be set to TRUE to use shiny() function on hdlm or hdlmm
TRUE or FALSE (default) keep model diagnostic such as the number of terminal nodes and acceptance ratio.
initial parameters for fixed effects model, FALSE = none (default), "glm" = generate using GLM, or user defined, length must equal number of parameters in fixed effects model.