Control settings for dlmtree model fitting, when used for mixture models
dlmtree.control.mix(interactions = "noself", sparsity.prior = 1)list of mixture control parameters.
'noself' (default) which estimates interactions only between two different exposures, 'all' which also allows interactions within the same exposure, or 'none' which eliminates all interactions and estimates only main effects of each exposure.
positive scalar hyperparameter for sparsity of exposures. (default: 1)