dlmtreeGPFixedGaussian: dlmtree model with fixed Gaussian process approach

View source: R/RcppExports.R

dlmtreeGPFixedGaussianR Documentation

dlmtree model with fixed Gaussian process approach

Description

dlmtree model with fixed Gaussian process approach

Usage

dlmtreeGPFixedGaussian(model)

Arguments

model

A list of parameter and data contained for the model fitting

Value

A list of dlmtree model fit, mainly posterior mcmc samples


dlmtree documentation built on Feb. 3, 2026, 9:07 a.m.