Learn R Programming

dlmtree (version 1.1.1)

dlmtreeGPGaussian: dlmtree model with Gaussian process approach

Description

dlmtree model with Gaussian process approach

Usage

dlmtreeGPGaussian(model)

Value

A list of dlmtree model fit, mainly posterior mcmc samples

Arguments

model

A list of parameter and data contained for the model fitting