Learn R Programming

dlmtree (version 1.1.1)

dlmtreeHDLMGaussian: dlmtree model with shared HDLM approach

Description

dlmtree model with shared HDLM approach

Usage

dlmtreeHDLMGaussian(model)

Value

A list of dlmtree model fit, mainly posterior mcmc samples

Arguments

model

A list of parameter and data contained for the model fitting