dlmtreeHDLMMGaussian: dlmtree model with HDLMM approach

View source: R/RcppExports.R

dlmtreeHDLMMGaussianR Documentation

dlmtree model with HDLMM approach

Description

dlmtree model with HDLMM approach

Usage

dlmtreeHDLMMGaussian(model)

Arguments

model

A list of parameter and data contained for the model fitting

Value

A list of dlmtree model fit, mainly posterior mcmc samples


dlmtree documentation built on Feb. 3, 2026, 9:07 a.m.