R/RcppExports.R
dlmtreeMixtures.Rd
dlmtree model with HDLMM approach
dlmtreeMixtures(model)
A list of parameter and data contained for the model fitting
A list of dlmtree model fit, mainly posterior mcmc samples