R/RcppExports.R
dlmtreeNested.Rd
dlmtree model with nested HDLM approach
dlmtreeNested(model)
A list of parameter and data contained for the model fitting
A list of dlmtree model fit, mainly posterior mcmc samples