Learn R Programming

dlmtree (version 1.1.1)

dlmtreeTDLMFixedGaussian: dlmtree model with fixed Gaussian approach

Description

dlmtree model with fixed Gaussian approach

Usage

dlmtreeTDLMFixedGaussian(model)

Value

A list of dlmtree model fit, mainly posterior mcmc samples

Arguments

model

A list of parameter and data contained for the model fitting