dlmtreeTDLMNestedGaussian: dlmtree model with nested Gaussian approach

View source: R/RcppExports.R

dlmtreeTDLMNestedGaussianR Documentation

dlmtree model with nested Gaussian approach

Description

dlmtree model with nested Gaussian approach

Usage

dlmtreeTDLMNestedGaussian(model)

Arguments

model

A list of parameter and data contained for the model fitting

Value

A list of dlmtree model fit, mainly posterior mcmc samples


dlmtree documentation built on Feb. 3, 2026, 9:07 a.m.