Learn R Programming

dlmtree (version 1.1.1)

exposureCov: Exposure covariance structure

Description

Matrix containing pairwise covariances for real exposure data consisting of five different exposures, each measured over 37 weeks.

Usage

data(exposureCov)

Arguments

Format

matrix

References

https://www.epa.gov/outdoor-air-quality-data