Learn R Programming

dlmtree (version 1.1.1)

monotdlnm_Cpp: dlmtree model with monotone tdlnm approach

Description

dlmtree model with monotone tdlnm approach

Usage

monotdlnm_Cpp(model)

Value

A list of dlmtree model fit, mainly posterior mcmc samples

Arguments

model

A list of parameter and data contained for the model fitting