Learn R Programming

dlmtree (version 1.1.1)

tdlmm_Cpp: dlmtree model with tdlmm approach

Description

dlmtree model with tdlmm approach

Usage

tdlmm_Cpp(model)

Value

A list of dlmtree model fit, mainly posterior mcmc samples

Arguments

model

A list of parameter and data contained for the model fitting