tdlnm_Cpp: dlmtree model with tdlnm approach

View source: R/RcppExports.R

tdlnm_CppR Documentation

dlmtree model with tdlnm approach

Description

dlmtree model with tdlnm approach

Usage

tdlnm_Cpp(model)

Arguments

model

A list of parameter and data contained for the model fitting

Value

A list of dlmtree model fit, mainly posterior mcmc samples


dlmtree documentation built on Feb. 3, 2026, 9:07 a.m.