Learn R Programming

dlmtree (version 1.1.1)

dlmtreeGPFixedGaussian: dlmtree model with fixed Gaussian process approach

Description

dlmtree model with fixed Gaussian process approach

Usage

dlmtreeGPFixedGaussian(model)

Value

A list of dlmtree model fit, mainly posterior mcmc samples

Arguments

model

A list of parameter and data contained for the model fitting