dlmtreeHDLMMGaussian: dlmtree model with HDLMM approach
Description
dlmtree model with HDLMM approach
Usage
dlmtreeHDLMMGaussian(model)
Value
A list of dlmtree model fit, mainly posterior mcmc samples
Arguments
- model
A list of parameter and data contained for the model fitting