Download simulated data for dlmtree articles
get_sbd_dlmtree()A data frame with 10000 rows (observations) and 202 variables. All data is simulated. The variables are:
Outcome to be used. Simulated birth weight for gestational age z-score.
Binary sex of child.
Continuous age in years.
Continuous estimated gestational age at birth in weeks.
Continuous maternal height in inches.
Continuous mothers pre-pregnancy weight in pounds.
Continuous mothers pre-pregnancy BMI.
Categorical race.
Binary indicator of Hispanic.
Categorical maternal highest educational attainment.
Binary indicator of any smoking during pregnancy.
Categorical maternal marital status.
Categorical income.
Estimated date of conception.
Estimated month of conception.
Estimated year of conception.
Weekly average exposure to PM2.5 for weeks 1 to 37. The columns are already scaled by the exposure IQR of 0.35.
Weekly average exposure to NO2 for weeks 1 to 37. The columns are already scaled by the exposure IQR of 9.13.
Weekly average exposure to SO2 for weeks 1 to 37. The columns are already scaled by the exposure IQR of 0.96.
Weekly average exposure to CO for weeks 1 to 37. The columns are already scaled by the exposure IQR of 0.15.
Weekly average exposure to temperature for weeks 1 to 37. The columns are already scaled by the exposure IQR of 27.93
Variable indicating that the data came from the bdlim package.
sbd_dlmtree <- get_sbd_dlmtree()
Run the code above in your browser using DataLab