Learn R Programming

dlmtree (version 1.1.1)

tdlnm_Cpp: dlmtree model with tdlnm approach

Description

dlmtree model with tdlnm approach

Usage

tdlnm_Cpp(model)

Value

A list of dlmtree model fit, mainly posterior mcmc samples

Arguments

model

A list of parameter and data contained for the model fitting